bayespy.inference.VB
====================

.. currentmodule:: bayespy.inference

.. autoclass:: VB

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~VB.__init__
      ~VB.add
      ~VB.compute_lowerbound
      ~VB.compute_lowerbound_terms
      ~VB.dot
      ~VB.get_gradients
      ~VB.get_iteration_by_nodes
      ~VB.get_parameters
      ~VB.gradient_step
      ~VB.has_converged
      ~VB.load
      ~VB.loglikelihood_lowerbound
      ~VB.optimize
      ~VB.pattern_search
      ~VB.plot
      ~VB.plot_iteration_by_nodes
      ~VB.save
      ~VB.set_annealing
      ~VB.set_autosave
      ~VB.set_callback
      ~VB.set_parameters
      ~VB.update
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: generated/
   
      ~VB.ignore_bound_checks
   
   